| Title: | Spatial Accessibility Measures |
|---|---|
| Description: | Provides a set of spatial accessibility measures from a set of locations (demand) to another set of locations (supply). It aims, among others, to support research on spatial accessibility to health care facilities. Includes the locations and some characteristics of major public hospitals in Greece. |
| Authors: | Stamatis Kalogirou [aut, cre] |
| Maintainer: | Stamatis Kalogirou <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1-6 |
| Built: | 2026-05-29 09:15:12 UTC |
| Source: | https://github.com/cran/SpatialAcc |
Provides a set of spatial accessibility measures from a set of locations (demand) to another set of locations (supply). It aims, among others, to support research on spatial accessibility to health care facilities. Includes the locations and some characteristics of major public hospitals in Greece.
| Package: | SpatialAcc |
| Type: | Package |
| Version: | 0.1-6 |
| Date: | 2026-04-28 |
| License: | GPL (>= 2) |
Stamatis Kalogirou
Maintainer: Stamatis Kalogirou <[email protected]>
Kalogirou, S., and Foley, R. (2006). Health, place and Hanly: Modelling accessibility to hospitals in Ireland. Irish Geography, 39(1), 52-68.
Kalogirou, S. (2017). Spatial inequality in the accessibility to hospitals in Greece, The International Archives of the Photogrammetry, Remote Sensing and Spatial Information Sciences, XLII-4/W2, 91-94, https://doi.org/10.5194/isprs-archives-XLII-4-W2-91-2017.
This function measures the accessibility of geographical areas to amenities.
The former usually refer to places of residence and the latter to services
such as health care, education, and culture. Several functions may define the
accessibility measure. See family for details.
ac(p, n, D, d0, power = 2, family = "SAM")ac(p, n, D, d0, power = 2, family = "SAM")
p |
a vector that quantifies the demand for services in each location, usually the population at risk. For example, it may be the number of older people interested in geriatric services at hospitals. |
n |
a vector that quantifies the supply of services in each location, usually a characteristic of the service. For example, it may be the number of beds at hospitals. |
D |
a matrix of a quantity separating the demand from the supply. This is usually a distance matrix, preferably using a road network distance or travel time through the road network. |
d0 |
the threshold distance or time that defines the catchment area (spatial kernel). Required when |
power |
the power of the separation variable. This is usually 2 from the theory of the gravity model in geography. |
family |
a character value defining the accessibility measure function: SAM are the initials of Spatial Accessibility Measure referring to the function |
SAM refers to the Spatial Accessibility Measure proposed by Kalogirou and Foley (2006).
A vector with accessibility measures for all locations (defined by the length of p).
Stamatis Kalogirou <[email protected]>
Kalogirou, S., and Foley, R. (2006). Health, place and Hanly: Modelling accessibility to hospitals in Ireland. Irish Geography, 39(1), 52-68.
Kalogirou, S. (2017). Spatial inequality in the accessibility to hospitals in Greece, The International Archives of the Photogrammetry, Remote Sensing and Spatial Information Sciences, XLII-4/W2, 91-94, https://doi.org/10.5194/isprs-archives-XLII-4-W2-91-2017.
n<-1:4 p<-20:25 D<-matrix(1:24, ncol=4, nrow=6) Acc.p <- ac(p, n, D)n<-1:4 p<-20:25 D<-matrix(1:24, ncol=4, nrow=6) Acc.p <- ac(p, n, D)
Computes Euclidean or Manhattan distances for all pairs of points between two sets of points.
distance(m1, m2, type = "euclidean")distance(m1, m2, type = "euclidean")
m1 |
a matrix or data frame containing origin point coordinates in the first two columns. |
m2 |
a matrix or data frame containing destination point coordinates in the first two columns. |
type |
the type of distance to be computed. Two types are currently supported: |
When m1 and m2 are identical, the function is equivalent to the dist function of base R.
A distance matrix in which rows refer to origins and columns refer to destinations.
Stamatis Kalogirou <[email protected]>
dist in stats.
m1 <- cbind(1:10, 1:10) m2 <- cbind(c(20, 40, 60, 80), c(25, 45, 65, 85)) d <- distance(m1, m2)m1 <- cbind(1:10, 1:10) m2 <- cbind(c(20, 40, 60, 80), c(25, 45, 65, 85)) d <- distance(m1, m2)
Locations of general and specialised hospitals in Greece.
data("GR.Hospitals")data("GR.Hospitals")
A SpatialPointsDataFrame with 132 observations on the following 15 variables.
Addresscharacter vector of hospitals' addresses
Namea character vector of hospitals' names
IDan integer vector of hospitals' IDs
Xa numeric vector of x coordinates (GGRS87 - Greek Grid)
Ya numeric vector of y coordinates (GGRS87 - Greek Grid)
Postcodea numeric vector of the hospitals' postcodes
URLa character vector of hospitals' websites
DYPEan integer vector of hospitals' Healthcare Regions
KallCodea character vector of municipality codes to link with data from the Hellenic Statistical Authority (EL.STAT.)
Dimosa character vector of municipality names (Greek with latin characters)
Lata numeric vector of hospitals' latitudes (WGS84)
Lona numeric vector of hospitals' longitudes (WGS84)
Beds15a integer vector of hospitals' beds in 2015
Patien15a integer vector of hospitals' admitted patients (hospital discharges) in 2015
Nights15a numeric vector of in-patients' nights in 2015
The X,Y coordinates (as well as the Lat/Lon coordinates) refer to the exact locations of operating hospitals in the summer 2016. The locations were identified from registry data, formal hospital addresses, OpenStreetMap (https://www.openstreetmap.org) and Google Maps (https://maps.google.com), including Street View. They were manually digitised by the author of this package.
The source of the hospital beds, hospital discharges and in-patient nights statistics is the Ministry of Health (http://www.moh.gov.gr/articles/bihealth/stoixeia-noshleytikhs-kinhshs/3865-stoixeia-noshleythentwn-sta-nosokomeia-toy-esy-etoys-2015?dl=1).
Kalogirou, S. (2017). Spatial inequality in the accessibility to hospitals in Greece, The International Archives of the Photogrammetry, Remote Sensing and Spatial Information Sciences, XLII-4/W2, 91-94, https://doi.org/10.5194/isprs-archives-XLII-4-W2-91-2017.
data(GR.Hospitals) hist(GR.Hospitals$Beds15)data(GR.Hospitals) hist(GR.Hospitals$Beds15)
Population weighted centroids of municipalities in Greece (Programme Kallikratis).
data("PWC.Municipalities")data("PWC.Municipalities")
A data frame with 326 observations on the following 6 variables.
KallCodea character vector of municipality codes to link with data from the Hellenic Statistical Authority (EL.STAT.)
pwXa numeric vector of population weighted x coordinates (GGRS87 / Greek Grid)
pwYa numeric vector of population weighted y coordinates (GGRS87 / Greek Grid)
Popa numeric vector of population according to the 2011 Census for Population in Greece
Lata numeric vector of municipalities' latitudes (WGS84)
Lona numeric vector of municipalities' longitudes (WGS84)
The population weighted centroids for the 325 Municipalities and the Holy Mountain (Agion Oros) in Greece were computed based on the 13,548 settlements' x and y coordinates and their total population in 2011.
Kalogirou, S. (2017). Spatial inequality in the accessibility to hospitals in Greece, The International Archives of the Photogrammetry, Remote Sensing and Spatial Information Sciences, XLII-4/W2, 91-94, https://doi.org/10.5194/isprs-archives-XLII-4-W2-91-2017.
data(PWC.Municipalities) plot(PWC.Municipalities$pwX,PWC.Municipalities$pwY) summary(PWC.Municipalities$Pop)data(PWC.Municipalities) plot(PWC.Municipalities$pwX,PWC.Municipalities$pwY) summary(PWC.Municipalities$Pop)